@@ -435,7 +435,7 @@ struct cdrom_drive * AudioCDProtocol::initRequest(const QUrl & url)
 		d->req_track = -1;
 
 	qCDebug(AUDIOCD_KIO_LOG) << "path=" << path << " file=" << d->fname
-		<< " req_track=" << d->req_track << " which_dir=" << d->which_dir << " full CD?=" << d->req_allTracks << endl;
+                << " req_track=" << d->req_track << " which_dir=" << d->which_dir << " full CD?=" << d->req_allTracks;
 	return drive;
 }
 
@@ -1069,7 +1069,11 @@ void AudioCDProtocol::parseURLArgs(const QUrl & url)
 	if (query.isEmpty())
 		return;
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
 	const QStringList tokens(query.split(QLatin1Char( '&' ),QString::SkipEmptyParts));
+#else
+	const QStringList tokens(query.split(QLatin1Char( '&' ),Qt::SkipEmptyParts));
+#endif
 
 	for (QStringList::ConstIterator it(tokens.constBegin()); it != tokens.constEnd(); ++it)
 	{
